#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optparse-generic
version:              1.4.4
visibility:           public
id:                   optparse-generic-1.4.4-c1E6iGZRpe4PDzwxLsx6B
key:                  optparse-generic-1.4.4-c1E6iGZRpe4PDzwxLsx6B
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Auto-generate a command-line parser for your datatype
description:
    This library auto-generates an @optparse-applicative@-compatible
    @Parser@ from any data type that derives the @Generic@ interface.

    See the documentation in "Options.Generic" for an example of how to use
    this library

category:             System
abi:                  40ef53d76f2e32bb55de6610465dbb90
exposed:              True
exposed-modules:      Options.Generic
import-dirs:          /usr/lib/ghc-8.10.5/site-local/optparse-generic-1.4.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/optparse-generic-1.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/optparse-generic-1.4.4
hs-libraries:         HSoptparse-generic-1.4.4-c1E6iGZRpe4PDzwxLsx6B
depends:
    Only-0.1-FUCJUAPDXF54dPZ4SnGX6G base-4.14.2.0 bytestring-0.10.12.0
    optparse-applicative-0.16.1.0-ARX6qDeExVWDKYrQ55nL8e
    system-filepath-0.4.14-EteQbvW1sOP6ea4Eitj1Mn text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2 void-0.7.3-72JC1ZJs2iULdltk7dpkuA

haddock-interfaces:
    /usr/share/doc/haskell-optparse-generic/html/optparse-generic.haddock

haddock-html:         /usr/share/doc/haskell-optparse-generic/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

